@@ -4,3 +4,8 @@ from flask_sqlalchemy import SQLAlchemy
 
 login = GoogleLogin()
 db = SQLAlchemy()
+
+
+def init(app):
+    login.init_app(app)
+    db.init_app(app)
